{% load i18n admin_static admin_modify thumbnails %}{% load cycle from future %}
<div class="inline-group" id="{{ inline_admin_formset.formset.prefix }}-group">
	<div class="wo-admin-gallery inline-related {% if forloop.last %}last-related{% endif %}">
{{ inline_admin_formset.formset.management_form }}
<fieldset>
	<h2>{{ inline_admin_formset.opts.verbose_name_plural|capfirst }}</h2>
	{{ inline_admin_formset.formset.non_form_errors }}

{% comment %}
	<table>
		<thead><tr>
		{% for field in inline_admin_formset.fields %}
			{% if not field.widget.is_hidden %}
				<th{% if forloop.first %} colspan="2"{% endif %}{% if field.required %} class="required"{% endif %}>{{ field.label|capfirst }}
				{% if field.help_text %}&nbsp;<img src="{% static "admin/img/icon-unknown.gif" %}" class="help help-tooltip" width="10" height="10" alt="({{ field.help_text|striptags }})" title="{{ field.help_text|striptags }}" />{% endif %}
				</th>
			{% endif %}
		{% endfor %}
		{% if inline_admin_formset.formset.can_delete %}<th>{% trans "Delete?" %}</th>{% endif %}
		</tr></thead>
{% endcomment %}

		{% for inline_admin_form in inline_admin_formset %}

{% comment %}
				<ul class="form-row {% cycle "row1" "row2" %} {% if inline_admin_form.original or inline_admin_form.show_url %}has_original{% endif %}{% if forloop.last %} empty-form{% endif %}" id="{{ inline_admin_formset.formset.prefix }}-{% if not forloop.last %}{{ forloop.counter0 }}{% else %}empty{% endif %}">
{% endcomment %}
				<ul class="wo-admin-gallery-element{% if inline_admin_form.original or inline_admin_form.show_url %} has_original{% endif %}{% if forloop.last %} empty-form{% endif %}" id="{{ inline_admin_formset.formset.prefix }}-{% if not forloop.last %}{{ forloop.counter0 }}{% else %}empty{% endif %}" >
					<li class="original" >
						{% if inline_admin_form.original %}<p>{{ inline_admin_form.original }}</p>{% endif %}
						{% if inline_admin_form.needs_explicit_pk_field %}{{ inline_admin_form.pk_field.field }}{% endif %}
						{{ inline_admin_form.fk_field.field }}
						{% spaceless %}
						{% for fieldset in inline_admin_form %}
							{% for line in fieldset %}
								{% for field in line %}
									{% if field.is_hidden %} {{ field.field }} {% endif %}
								{% endfor %}
							{% endfor %}
						{% endfor %}
						{% endspaceless %}
					</li>

					{% for fieldset in inline_admin_form %}
						{% for line in fieldset %}
							{% for field in line %}
								<li{% if field.field.name %} class="field-{{ field.field.name }}"{% endif %}>
									<label for="id_{{ inline_admin_formset.formset.prefix }}-{% if not forloop.parentloop.parentloop.parentloop.last %}{{ forloop.parentloop.parentloop.parentloop.counter0 }}{% else %}empty{% endif %}-{{ field.field.name }}" class="wo-admin-gallery-label" >{{ field.field.label|capfirst }}:</label for="id_date">
									{% if field.is_readonly %}
										{{ field.contents|linebreaksbr }}
									{% else %}
										{{ field.field.errors.as_ul }}
										{{ field.field }}
									{% endif %}
								</li>
							{% endfor %}
						{% endfor %}
					{% endfor %}
					{% if inline_admin_formset.formset.can_delete %}
						<li class="delete">{% if inline_admin_form.original %}{{ inline_admin_form.deletion_field.field }}{% endif %}</li>
					{% endif %}
				</ul>
		{% endfor %}

{% comment %}
	</table>
{% endcomment %}
</fieldset>
	</div>
</div>

<script type="text/javascript">
	(function($) {
		$("#{{ inline_admin_formset.formset.prefix }}-group .wo-admin-gallery.inline-related ul.wo-admin-gallery-element").tabularFormset({
			prefix: "{{ inline_admin_formset.formset.prefix }}",
			adminStaticPrefix: '{% static "admin/" %}',
			addText: "{% blocktrans with inline_admin_formset.opts.verbose_name|title as verbose_name %}Add another {{ verbose_name }}{% endblocktrans %}",
			deleteText: "{% trans 'Remove' %}"
		});
	})(django.jQuery);
</script>
