{% extends "base.html" %}

{% load static i18n %}


{% block title %}{% trans 'ошибка' %} 404 :: {{ SITE_NAME }}{% endblock %}

{% block extrahead %}
	{# <link type="text/css" rel="stylesheet" href="{% static 'css/weboven::main.css' %}" > #}
{% endblock %}

{% block content %}<div class="error_list error404">
	<p class="error_number_line" >{% trans 'ошибка' %} <span class="error_number" >404</span></p>
	<p class="error_text" >{% trans 'такой страницы не существует, попробуйте начать' %} <a href="/">{% trans 'сначала' %}</a> {% trans 'или вернитесь' %} <a href="{{ request.META.HTTP_REFERER }}">{% trans 'назад' %}</a></p>
</div>{% endblock %}
